@@ -1,10 +1,8 @@
-import logging, os, zipfile, hashlib, sys, pulsar, datetime
-from .config import Conf
+import logging, os, zipfile, hashlib, sys
+from .configuration import Conf
 import json
 from shutil import copyfile, rmtree
 from appdirs import user_config_dir
-from pulsar import ConsumerType
-from pulsar import InitialPosition
 import requests
 from requests_toolbelt.multipart.encoder import MultipartEncoder
 dirname = os.path.dirname(os.path.realpath(__file__))
@@ -18,9 +16,8 @@ def start(args):
     print(args)
     if args.command == 'upload':
         if 'project_folder' in args:
-            root_path = os.getcwd()
             tmp_path = '/tmp/'
-            path = root_path + '/' + args.project_folder
+            path = os.path.join(os.getcwd(), args.project_folder)
             if os.path.isdir(path):
                 if os.path.exists(f"{path}/config.py"):
                     # Delete existing dependencies
@@ -30,27 +27,11 @@ def start(args):
                     sys.path.append(path)
                     project_config = __import__('config')
 
-                    copyfile(os.path.join(dirname, 'assets/pandioml-1.0.5-py3-none-any.whl'),
-                             os.path.join(path, 'deps/pandioml-1.0.5-py3-none-any.whl'))
+                    print("Getting project requirements...")
 
-                    if 'ADMIN_API' in project_config.pandio and 'localhost' in project_config.pandio['ADMIN_API']:
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    -r {dirname}/assets/pandioml_requirements.txt -d {path}/deps")
-
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    -r {path}/requirements.txt -d {path}/deps")
-                    else:
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    --platform manylinux1_x86_64 \
-                                    --python-version 37 -r {dirname}/assets/pandioml_requirements.txt -d {path}/deps")
-
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    --platform manylinux1_x86_64 \
-                                    --python-version 37 -r {path}/requirements.txt -d {path}/deps")
+                    f = open(f"{path}/pandio_requirements.txt", "w")
+                    f.write("pandioml>=1.0.6")
+                    f.close()
 
                     hash = hashlib.md5(bytes(args.project_folder, 'utf-8'))
                     tmp_path = tmp_path + hash.hexdigest() + '/'
@@ -64,6 +45,11 @@ def start(args):
                     zipf.close()
                     print(f"File located at {tmp_path}{tmp_file}")
 
+                    if os.path.exists(f"{path}/deps"):
+                        rmtree(f"{path}/deps")
+
+                    os.remove(f"{path}/pandio_requirements.txt")
+
                     arr = {
                         "name": project_config.pandio['FUNCTION_NAME'],
                         "inputs": project_config.pandio['INPUT_TOPICS'],
@@ -72,12 +58,7 @@ def start(args):
                         "className": 'wrapper.Wrapper',
                         "py": tmp_file,
                         "runtime": "PYTHON",
-                        "inputSpecs": {
-                            "persistent://public/default/in": {
-                                "initialPosition": InitialPosition.Earliest,
-                                "receiverQueueSize": 10
-                            }
-                        }
+                        "inputSpecs": {}
                     }
 
                     mp_encoder = MultipartEncoder(
